@@ -58,6 +58,10 @@ class Settings:
     def FLAVIUS_API_HEADER_CREATE(self):
         return getattr(settings, "FLAVIUS_API_HEADER_CREATE", 'api/header_create.php')
 
+    @property
+    def FLAVIUS_API_HEADER_MODIFY(self):
+        return getattr(settings, "FLAVIUS_API_HEADER_MODIFY", 'api/header_modify.php')
+
     @property
     def FLAVIUS_API_HEADER_FETCH(self):
         return getattr(settings, "FLAVIUS_API_HEADER_FETCH", 'api/header_fetch.php')
